==> dataone.cli-2.3.7-py2-none-any.whl: d1_cli/tests/test_check_dependencies.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

# This work was created by participants in the DataONE project, and is
# jointly copyrighted by participating institutions in DataONE. For
# more information on DataONE, see our web site at http://dataone.org.
#
#   Copyright 2009-2016 DataONE
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Test dependency checker
"""

from __future__ import absolute_import

import d1_cli.impl.check_dependencies

import d1_test.d1_test_case


class TestCheckDependencies(d1_test.d1_test_case.D1TestCase):
  def test_1000(self):
    """check_dependencies(): Returns True given modules known to be present"""
    assert d1_cli.impl.check_dependencies.are_modules_importable(['os', 'sys'])

  def test_1010(self):
    """check_dependencies(): Returns false and logs error on invalid module"""
    with d1_test.d1_test_case.capture_log() as log_stream:
      assert not d1_cli.impl.check_dependencies. \
        are_modules_importable(['os', 'invalid_module'])
    assert 'dependencies failed' in log_stream.getvalue()

==> dataone.cli-2.4.1-py2-none-any.whl: d1_cli/tests/test_check_dependencies.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

# This work was created by participants in the DataONE project, and is
# jointly copyrighted by participating institutions in DataONE. For
# more information on DataONE, see our web site at http://dataone.org.
#
#   Copyright 2009-2016 DataONE
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Test dependency checker
"""

from __future__ import absolute_import

import d1_cli.impl.check_dependencies

import d1_test.d1_test_case


class TestCheckDependencies(d1_test.d1_test_case.D1TestCase):
  def test_1000(self):
    """check_dependencies(): Returns True given modules known to be present"""
    assert d1_cli.impl.check_dependencies.are_modules_importable(['os', 'sys'])

  def test_1010(self, caplog):
    """check_dependencies(): Returns false and logs error on invalid module"""
    assert not (
      d1_cli.impl.check_dependencies.are_modules_importable(
        ['os', 'invalid_module']
      )
    )
    assert 'dependencies failed' in d1_test.d1_test_case.get_caplog_text(caplog)
